package secure

type Secure struct {
	Default       string
	Blank         string  `json:""`
	Ignore        string  `json:"-"`
	Named         string  `json:"named"`
	Empty         string  `json:"empty"`
	Omit          string  `json:"omit,omitempty"`
	Number        int     `json:"number"`
	Float         float64 `json:"float"`
	SecureDefault string  `json:",secure"`
	SecureBlank   string  `json:",secure"`
	SecureIgnore  string  `json:"-"`
	SecureNamed   string  `json:"named_secure,secure"`
	SecureEmpty   string  `json:"empty_secure,secure"`
	SecureOmit    string  `json:"omit_secure,omitempty,secure"`
	SecureNumber  int     `json:"number_secure,secure"`
	SecureFloat   float64 `json:"float_secure,secure"`
}

var secObj = &Secure{
	Default:       "default-value",
	Blank:         "blank-value",
	Ignore:        "ignore-value",
	Named:         "named-value",
	Empty:         "",
	Number:        42,
	Float:         99.9,
	SecureDefault: "default-secure",
	SecureBlank:   "blank-secure",
	SecureIgnore:  "ignore-secure",
	SecureNamed:   "named-secure",
	SecureEmpty:   "",
	SecureNumber:  42,
	SecureFloat:   99.9,
}

var secDecoded = &Secure{
	Default:       "default-value",
	Blank:         "blank-value",
	Named:         "named-value",
	Number:        42,
	Float:         99.9,
	SecureDefault: "default-secure",
	SecureBlank:   "blank-secure",
	SecureNamed:   "named-secure",
	SecureNumber:  42,
	SecureFloat:   99.9,
}

var secSparse = &Secure{
	Default: "default-value",
	Blank:   "blank-value",
	Named:   "named-value",
	Number:  42,
	Float:   99.9,
}

var secMap = map[string]interface{}{
	"Blank":         "blank-value",
	"Default":       "default-value",
	"SecureBlank":   "blank-secure",
	"SecureDefault": "default-secure",
	"empty":         "",
	"empty_secure":  "",
	"float":         99.9,
	"float_secure":  99.9,
	"named":         "named-value",
	"named_secure":  "named-secure",
	"number":        42.0,
	"number_secure": 42.0,
}

var secMapSparse = map[string]interface{}{
	"Blank":         "blank-value",
	"Default":       "default-value",
	"SecureBlank":   "",
	"SecureDefault": "",
	"empty":         "",
	"empty_secure":  "",
	"float":         99.9,
	"float_secure":  0.0,
	"named":         "named-value",
	"named_secure":  "",
	"number":        42.0,
	"number_secure": 0.0,
}

var secEncoded = []byte(`{"Default":"default-value","Blank":"blank-value","na` +
	`med":"named-value","empty":"","number":42,"float":99.9,"SecureDefault":"` +
	`cn86fb3fa00_24","SecureBlank":"cn86fb3fa01_24","named_secure":"cn86fb3fa` +
	`02_24","empty_secure":"cn86fb3fa03_24","number_secure":"cn86fb3fa04_2","` +
	`float_secure":"cn86fb3fa05_14"}`)

var secUnsealed = []byte(`{"Default":"default-value","Blank":"blank-value","n` +
	`amed":"named-value","empty":"","number":42,"float":99.9,"SecureDefault":` +
	`"cn86fb3fa00_24","SecureBlank":"cn86fb3fa01_24","named_secure":"cn86fb3f` +
	`a02_24","empty_secure":"cn86fb3fa03_24","number_secure":"cn86fb3fa04_2",` +
	`"float_secure":"cn86fb3fa05_14"}`)

var secSealed = []byte{0x6a, 0xff, 0x81, 0x3, 0x1, 0x1, 0x7, 0x50, 0x61,
	0x63, 0x6b, 0x61, 0x67, 0x65, 0x1, 0xff, 0x82, 0x0, 0x1, 0x7, 0x1, 0x7,
	0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x1, 0xc, 0x0, 0x1, 0x6, 0x46,
	0x6f, 0x72, 0x6d, 0x61, 0x74, 0x1, 0xc, 0x0, 0x1, 0xa, 0x43, 0x6f, 0x6d,
	0x70, 0x72, 0x65, 0x73, 0x73, 0x65, 0x64, 0x1, 0x2, 0x0, 0x1, 0x9, 0x45,
	0x6e, 0x63, 0x6f, 0x64, 0x65, 0x72, 0x49, 0x44, 0x1, 0xc, 0x0, 0x1, 0x5,
	0x54, 0x6f, 0x6b, 0x65, 0x6e, 0x1, 0xc, 0x0, 0x1, 0x6, 0x43, 0x69, 0x70,
	0x68, 0x65, 0x72, 0x1, 0xa, 0x0, 0x1, 0x7, 0x45, 0x6e, 0x63, 0x6f, 0x64,
	0x65, 0x64, 0x1, 0xa, 0x0, 0x0, 0x0, 0xfe, 0x2, 0x9b, 0xff, 0x82, 0x1, 0x5,
	0x30, 0x2e, 0x30, 0x2e, 0x31, 0x1, 0x6, 0x73, 0x70, 0x61, 0x72, 0x73, 0x65,
	0x2, 0x8, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x1, 0xa, 0x63,
	0x6e, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x1, 0xfe, 0x1, 0x40,
	0x37, 0x62, 0x32, 0x32, 0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36,
	0x36, 0x36, 0x36, 0x32, 0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30,
	0x33, 0x30, 0x35, 0x66, 0x33, 0x32, 0x33, 0x34, 0x32, 0x32, 0x33, 0x61,
	0x32, 0x32, 0x36, 0x34, 0x36, 0x35, 0x36, 0x36, 0x36, 0x31, 0x37, 0x35,
	0x36, 0x63, 0x37, 0x34, 0x32, 0x64, 0x37, 0x33, 0x36, 0x35, 0x36, 0x33,
	0x37, 0x35, 0x37, 0x32, 0x36, 0x35, 0x32, 0x32, 0x32, 0x63, 0x32, 0x32,
	0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36, 0x36, 0x36, 0x36, 0x32,
	0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30, 0x33, 0x31, 0x35, 0x66,
	0x33, 0x32, 0x33, 0x34, 0x32, 0x32, 0x33, 0x61, 0x32, 0x32, 0x36, 0x32,
	0x36, 0x63, 0x36, 0x31, 0x36, 0x65, 0x36, 0x62, 0x32, 0x64, 0x37, 0x33,
	0x36, 0x35, 0x36, 0x33, 0x37, 0x35, 0x37, 0x32, 0x36, 0x35, 0x32, 0x32,
	0x32, 0x63, 0x32, 0x32, 0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36,
	0x36, 0x36, 0x36, 0x32, 0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30,
	0x33, 0x32, 0x35, 0x66, 0x33, 0x32, 0x33, 0x34, 0x32, 0x32, 0x33, 0x61,
	0x32, 0x32, 0x36, 0x65, 0x36, 0x31, 0x36, 0x64, 0x36, 0x35, 0x36, 0x34,
	0x32, 0x64, 0x37, 0x33, 0x36, 0x35, 0x36, 0x33, 0x37, 0x35, 0x37, 0x32,
	0x36, 0x35, 0x32, 0x32, 0x32, 0x63, 0x32, 0x32, 0x36, 0x33, 0x36, 0x65,
	0x33, 0x38, 0x33, 0x36, 0x36, 0x36, 0x36, 0x32, 0x33, 0x33, 0x36, 0x36,
	0x36, 0x31, 0x33, 0x30, 0x33, 0x33, 0x35, 0x66, 0x33, 0x32, 0x33, 0x34,
	0x32, 0x32, 0x33, 0x61, 0x32, 0x32, 0x32, 0x32, 0x32, 0x63, 0x32, 0x32,
	0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36, 0x36, 0x36, 0x36, 0x32,
	0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30, 0x33, 0x34, 0x35, 0x66,
	0x33, 0x32, 0x32, 0x32, 0x33, 0x61, 0x33, 0x34, 0x33, 0x32, 0x32, 0x63,
	0x32, 0x32, 0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36, 0x36, 0x36,
	0x36, 0x32, 0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30, 0x33, 0x35,
	0x35, 0x66, 0x33, 0x31, 0x33, 0x34, 0x32, 0x32, 0x33, 0x61, 0x33, 0x39,
	0x33, 0x39, 0x32, 0x65, 0x33, 0x39, 0x37, 0x64, 0x1, 0xfe, 0x1, 0x2b, 0x7b,
	0x22, 0x44, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74, 0x22, 0x3a, 0x22, 0x64,
	0x65, 0x66, 0x61, 0x75, 0x6c, 0x74, 0x2d, 0x76, 0x61, 0x6c, 0x75, 0x65,
	0x22, 0x2c, 0x22, 0x42, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x3a, 0x22, 0x62,
	0x6c, 0x61, 0x6e, 0x6b, 0x2d, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x22, 0x2c,
	0x22, 0x6e, 0x61, 0x6d, 0x65, 0x64, 0x22, 0x3a, 0x22, 0x6e, 0x61, 0x6d,
	0x65, 0x64, 0x2d, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x22, 0x2c, 0x22, 0x65,
	0x6d, 0x70, 0x74, 0x79, 0x22, 0x3a, 0x22, 0x22, 0x2c, 0x22, 0x6e, 0x75,
	0x6d, 0x62, 0x65, 0x72, 0x22, 0x3a, 0x34, 0x32, 0x2c, 0x22, 0x66, 0x6c,
	0x6f, 0x61, 0x74, 0x22, 0x3a, 0x39, 0x39, 0x2e, 0x39, 0x2c, 0x22, 0x53,
	0x65, 0x63, 0x75, 0x72, 0x65, 0x44, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74,
	0x22, 0x3a, 0x22, 0x63, 0x6e, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61,
	0x30, 0x30, 0x5f, 0x32, 0x34, 0x22, 0x2c, 0x22, 0x53, 0x65, 0x63, 0x75,
	0x72, 0x65, 0x42, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x3a, 0x22, 0x63, 0x6e,
	0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x31, 0x5f, 0x32, 0x34,
	0x22, 0x2c, 0x22, 0x6e, 0x61, 0x6d, 0x65, 0x64, 0x5f, 0x73, 0x65, 0x63,
	0x75, 0x72, 0x65, 0x22, 0x3a, 0x22, 0x63, 0x6e, 0x38, 0x36, 0x66, 0x62,
	0x33, 0x66, 0x61, 0x30, 0x32, 0x5f, 0x32, 0x34, 0x22, 0x2c, 0x22, 0x65,
	0x6d, 0x70, 0x74, 0x79, 0x5f, 0x73, 0x65, 0x63, 0x75, 0x72, 0x65, 0x22,
	0x3a, 0x22, 0x63, 0x6e, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30,
	0x33, 0x5f, 0x32, 0x34, 0x22, 0x2c, 0x22, 0x6e, 0x75, 0x6d, 0x62, 0x65,
	0x72, 0x5f, 0x73, 0x65, 0x63, 0x75, 0x72, 0x65, 0x22, 0x3a, 0x22, 0x63,
	0x6e, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x34, 0x5f, 0x32,
	0x22, 0x2c, 0x22, 0x66, 0x6c, 0x6f, 0x61, 0x74, 0x5f, 0x73, 0x65, 0x63,
	0x75, 0x72, 0x65, 0x22, 0x3a, 0x22, 0x63, 0x6e, 0x38, 0x36, 0x66, 0x62,
	0x33, 0x66, 0x61, 0x30, 0x35, 0x5f, 0x31, 0x34, 0x22, 0x7d, 0x0}

var secComp = []byte{0x6a, 0xff, 0x81, 0x3, 0x1, 0x1, 0x7, 0x50, 0x61,
	0x63, 0x6b, 0x61, 0x67, 0x65, 0x1, 0xff, 0x82, 0x0, 0x1, 0x7, 0x1, 0x7,
	0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x1, 0xc, 0x0, 0x1, 0x6, 0x46,
	0x6f, 0x72, 0x6d, 0x61, 0x74, 0x1, 0xc, 0x0, 0x1, 0xa, 0x43, 0x6f, 0x6d,
	0x70, 0x72, 0x65, 0x73, 0x73, 0x65, 0x64, 0x1, 0x2, 0x0, 0x1, 0x9, 0x45,
	0x6e, 0x63, 0x6f, 0x64, 0x65, 0x72, 0x49, 0x44, 0x1, 0xc, 0x0, 0x1, 0x5,
	0x54, 0x6f, 0x6b, 0x65, 0x6e, 0x1, 0xc, 0x0, 0x1, 0x6, 0x43, 0x69, 0x70,
	0x68, 0x65, 0x72, 0x1, 0xa, 0x0, 0x1, 0x7, 0x45, 0x6e, 0x63, 0x6f, 0x64,
	0x65, 0x64, 0x1, 0xa, 0x0, 0x0, 0x0, 0xfe, 0x1, 0x9f, 0xff, 0x82, 0x1, 0x5,
	0x30, 0x2e, 0x30, 0x2e, 0x31, 0x1, 0x6, 0x73, 0x70, 0x61, 0x72, 0x73, 0x65,
	0x1, 0x1, 0x1, 0x8, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x1,
	0xa, 0x63, 0x6e, 0x38, 0x36, 0x66, 0x62, 0x33, 0x66, 0x61, 0x30, 0x1, 0xff,
	0xcc, 0x32, 0x38, 0x62, 0x35, 0x32, 0x66, 0x66, 0x64, 0x30, 0x34, 0x30,
	0x30, 0x63, 0x64, 0x30, 0x32, 0x30, 0x30, 0x32, 0x34, 0x30, 0x34, 0x37,
	0x62, 0x32, 0x32, 0x36, 0x33, 0x36, 0x65, 0x33, 0x38, 0x33, 0x36, 0x36,
	0x36, 0x36, 0x32, 0x33, 0x33, 0x36, 0x36, 0x36, 0x31, 0x33, 0x30, 0x33,
	0x30, 0x35, 0x66, 0x33, 0x32, 0x33, 0x34, 0x32, 0x32, 0x33, 0x61, 0x32,
	0x32, 0x36, 0x34, 0x36, 0x35, 0x36, 0x36, 0x36, 0x31, 0x37, 0x35, 0x36,
	0x63, 0x37, 0x34, 0x32, 0x64, 0x37, 0x33, 0x36, 0x35, 0x36, 0x33, 0x37,
	0x35, 0x37, 0x32, 0x36, 0x35, 0x32, 0x32, 0x32, 0x63, 0x33, 0x31, 0x36,
	0x32, 0x36, 0x63, 0x36, 0x31, 0x36, 0x65, 0x36, 0x62, 0x33, 0x32, 0x36,
	0x65, 0x36, 0x31, 0x36, 0x64, 0x36, 0x35, 0x36, 0x34, 0x33, 0x33, 0x33,
	0x34, 0x35, 0x66, 0x33, 0x32, 0x32, 0x32, 0x33, 0x61, 0x33, 0x34, 0x33,
	0x32, 0x33, 0x35, 0x35, 0x66, 0x33, 0x31, 0x33, 0x34, 0x32, 0x32, 0x33,
	0x61, 0x33, 0x39, 0x33, 0x39, 0x32, 0x65, 0x33, 0x39, 0x37, 0x64, 0x30,
	0x38, 0x30, 0x30, 0x33, 0x36, 0x39, 0x63, 0x35, 0x64, 0x66, 0x38, 0x30,
	0x30, 0x31, 0x38, 0x32, 0x65, 0x61, 0x30, 0x30, 0x61, 0x33, 0x30, 0x33,
	0x36, 0x31, 0x34, 0x37, 0x64, 0x34, 0x35, 0x36, 0x31, 0x62, 0x31, 0x36,
	0x32, 0x61, 0x38, 0x32, 0x37, 0x39, 0x65, 0x37, 0x33, 0x33, 0x33, 0x32,
	0x31, 0x1, 0xff, 0xa3, 0x28, 0xb5, 0x2f, 0xfd, 0x44, 0x0, 0x2b, 0x0, 0xa5,
	0x4, 0x0, 0x22, 0x7, 0x18, 0x1b, 0x70, 0x69, 0x15, 0x20, 0x8a, 0xa5, 0xa6,
	0x46, 0x5a, 0x76, 0x37, 0xad, 0xc5, 0x63, 0x67, 0xc5, 0x71, 0x42, 0x87,
	0x58, 0x23, 0x31, 0x6c, 0xbf, 0xfe, 0xff, 0xbd, 0x8d, 0x2b, 0x84, 0x5,
	0x9e, 0x98, 0x4a, 0x52, 0x82, 0x21, 0x57, 0x89, 0x21, 0xa4, 0x2e, 0x69,
	0x4e, 0x30, 0x68, 0x65, 0x9b, 0xa8, 0xac, 0xe1, 0x67, 0x1, 0xd6, 0xca,
	0x43, 0x3d, 0xb0, 0xfb, 0x49, 0x2a, 0xdf, 0x6c, 0x7b, 0xb1, 0x7f, 0xfe,
	0xfc, 0x2, 0x22, 0xde, 0xe6, 0x97, 0x7d, 0xda, 0x4c, 0x2b, 0xb7, 0xe7,
	0x99, 0x56, 0x26, 0xfc, 0x7c, 0x23, 0xab, 0xe2, 0x58, 0x9e, 0x87, 0x1c,
	0xd5, 0x6d, 0xe1, 0x8c, 0x14, 0x0, 0x42, 0x29, 0x80, 0x19, 0x97, 0x88,
	0x52, 0xe0, 0x18, 0xc, 0x60, 0x38, 0xa0, 0x71, 0x30, 0x2, 0xc0, 0x70, 0x43,
	0x2f, 0x24, 0x71, 0xd8, 0x87, 0x16, 0x0, 0x9f, 0xd0, 0x1d, 0x7a, 0x20, 0x0,
	0x51, 0x52, 0x35, 0x87, 0xad, 0xa0, 0xac, 0x95, 0xb1, 0xe5, 0x2c, 0x4d,
	0x87, 0xf2, 0x5, 0x61, 0xe4, 0xde, 0x51, 0x0}
